summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/MainDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/MainDlg.h')
-rw-r--r--kmplot/kmplot/MainDlg.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/kmplot/kmplot/MainDlg.h b/kmplot/kmplot/MainDlg.h
index 7b4d83bf..8609de0e 100644
--- a/kmplot/kmplot/MainDlg.h
+++ b/kmplot/kmplot/MainDlg.h
@@ -28,7 +28,7 @@
#ifndef MainDlg_included
#define MainDlg_included
-// Qt includes
+// TQt includes
#include <tqpicture.h>
// KDE includes
@@ -70,14 +70,15 @@ class BrowserExtension;
class MainDlg : public KParts::ReadOnlyPart, virtual public MainDlgIface
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constuctor.
* @param parentWidget parent widget for this part
* @param parent parent object
* @param name name of this dialog
*/
- MainDlg(TQWidget *parentWidget, const char *, TQObject *parent, const char *name);
+ MainDlg(TQWidget *tqparentWidget, const char *, TQObject *tqparent, const char *name);
/// Cleaning up a bit.
virtual ~MainDlg();
/// This class needs access to private members, too.
@@ -184,7 +185,7 @@ private:
KmPlotIO *kmplotio;
/// Set to true if the application is readonly
bool m_readonly;
- /// MainDlg's parent widget
+ /// MainDlg's tqparent widget
TQWidget *m_parent;
/// Current file
KURL m_currentfile;
@@ -216,11 +217,12 @@ protected slots:
class KmPlotPartFactory : public KParts::Factory
{
Q_OBJECT
+ TQ_OBJECT
public:
KmPlotPartFactory();
virtual ~KmPlotPartFactory();
- virtual KParts::Part* createPartObject( TQWidget *parentWidget, const char *widgetName,
- TQObject *parent, const char *name,
+ virtual KParts::Part* createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+ TQObject *tqparent, const char *name,
const char *classname, const TQStringList &args );
static KInstance* instance();
@@ -232,6 +234,7 @@ private:
class BrowserExtension : public KParts::BrowserExtension
{
Q_OBJECT
+ TQ_OBJECT
public:
BrowserExtension(MainDlg*);
@@ -70,14 +70,15 @@ class BrowserExtension;
public:
/** Constuctor.
- * @param parentWidget parent widget for this part
- * @param parent parent object
+ * @param tqparentWidget tqparent widget for this part
+ * @param tqparent tqparent object
* @param name name of this dialog
*/